@@ -61,16 +61,17 @@ POLICY_SCHEMA = Schema(
         Optional('Suppressions'): [str],
         Optional('Tags'): [str],
         Optional('Reports'): {
-            str: object
+            str: list
         },
         Optional('Tests'): [{
             'Name': str,
-            'ResourceType': str,
+            Optional('ResourceType'):
+                str,  # Not needed anymore, optional for backwards compatibility
             'ExpectedResult': bool,
             'Resource': object,
         }],
     },
-    ignore_extra_keys=False)
+    ignore_extra_keys=False)  # Prevent user typos on optional fields
 
 RULE_SCHEMA = Schema(
     {
@@ -98,13 +99,14 @@ RULE_SCHEMA = Schema(
         Optional('Suppressions'): [str],
         Optional('Tags'): [str],
         Optional('Reports'): {
-            str: object
+            str: list
         },
         Optional('Tests'): [{
             'Name': str,
-            'LogType': str,
+            Optional('LogType'):
+                str,  # Not needed anymore, optional for backwards compatibility
             'ExpectedResult': bool,
             'Log': object,
         }],
     },
-    ignore_extra_keys=False)
+    ignore_extra_keys=False)  # Prevent user typos on optional fields
